searchData={"items":[{"type":"module","title":"Streamline","doc":"Streamline provides a custom pipeline operator `~>` for working with Elixir pipelines\nthat handle `{:ok, _}` and `{:error, _}` tuples seamlessly.\n\nThis library enables clean and readable pipelines by:\n- Passing values from `{:ok, value}` to the next function in the pipeline.\n- Propagating `{:error, reason}` tuples without further processing.\n- Wrapping plain values in `{:ok, _}` to maintain consistency.","ref":"Streamline.html"},{"type":"module","title":"Motivation - Streamline","doc":"In Elixir, it's common to handle `{:ok, _}` and `{:error, _}` tuples using the `with` construct.\nWhile powerful, `with` can become verbose and less readable for sequential operations. For example:\n\n    with {:ok, params} <- build_foo(params),\n         {:ok, params} <- build_bar(params) do\n      build_baz(params)\n    end\n\nStreamline simplifies this pattern by allowing the same logic to be written as a clean and\nreadable pipeline:\n\n    params\n    ~> build_foo()\n    ~> build_bar()\n    ~> build_baz()","ref":"Streamline.html#module-motivation"},{"type":"module","title":"Installation - Streamline","doc":"def deps do\n      [\n        {:streamline, \"~> 0.1\"}\n      ]\n    end","ref":"Streamline.html#module-installation"},{"type":"module","title":"Usage - Streamline","doc":"Import `Streamline` to use the `~>` operator.","ref":"Streamline.html#module-usage"},{"type":"module","title":"Examples - Streamline","doc":"iex> import Streamline\n\n    # A successful pipeline\n    iex> {:ok, 5}\n    ...> ~> then(fn x -> {:ok, x * 2} end)\n    ...> ~> then(fn x -> x + 3 end)\n    {:ok, 13}\n\n    # Stopping on an error\n    iex> {:ok, 5}\n    ...> ~> then(fn _ -> {:error, \"failure\"} end)\n    ...> ~> then(fn x -> {:ok, x * 2} end)\n    {:error, \"failure\"}\n\n    # Wrapping a plain value\n    iex> 5\n    ...> ~> then(fn x -> x * 2 end)\n    {:ok, 10}","ref":"Streamline.html#module-examples"},{"type":"macro","title":"Streamline.~>/2","doc":"Custom pipeline operator for handling `{:ok, _}` and `{:error, _}` tuples.\n\nPasses the result of one computation to the next in a pipeline,\npropagating errors or wrapping plain values as needed.","ref":"Streamline.html#~%3E/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}